@@ -1,5 +1,5 @@
 package BalanceOfPower::Constants;
-$BalanceOfPower::Constants::VERSION = '0.400105';
+$BalanceOfPower::Constants::VERSION = '0.400110';
 use strict;
 use warnings;
 
@@ -140,6 +140,14 @@ use constant NOT_LOWERED_PRICE_FRIENDSHIP_MALUS => -2;
 use constant FRIENDSHIP_LIMIT_TO_SHOP => 30;
 use constant LOWER_MY_PRICE_FACTOR => 0.4;
 
+#Missions
+use constant FRIENDSHIP_RANGE_FOR_MISSION => { 'parcel' => [-7, +7] };
+use constant MONEY_RANGE_FOR_MISSION => { 'parcel' => [100, 500] };
+use constant BONUS_FACTOR_FOR_BAD_FRIENSHIP => 15;
+use constant MISSIONS_TO_GENERATE_PER_TURN => 40;
+use constant MAX_MISSIONS_FOR_USER => 1;
+use constant PENALTY_FACTOR_FOR_DROP_MISSION => .5;
+
 #Others
 use constant TRADEROUTE_SIZE_BONUS => .5;
 use constant PRODUCTION_UNITS => [ 2, 3, 4 ];
@@ -309,5 +317,11 @@ our @EXPORT_OK = ('MIN_EXPORT_QUOTE',
                   'LOWERED_PRICE_FRIENDSHIP_BONUS',
                   'NOT_LOWERED_PRICE_FRIENDSHIP_MALUS',
                   'EVENT_TURNS_TO_DUMP',
+                  'FRIENDSHIP_RANGE_FOR_MISSION',
+                  'MONEY_RANGE_FOR_MISSION',
+                  'BONUS_FACTOR_FOR_BAD_FRIENSHIP',
+                  'MISSIONS_TO_GENERATE_PER_TURN',
+                  'MAX_MISSIONS_FOR_USER',
+                  'PENALTY_FACTOR_FOR_DROP_MISSION',
                 );
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
